/**
  ******************************************************************************
  * @file           : main.c
  * @brief          : Main program body
  ******************************************************************************
  * Desk clock "Электроника Альфа 12-41А"
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "digits.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
volatile flag_t Flag = {0};
static rtc_t Clock;

/* Private function prototypes -----------------------------------------------*/
static void Show_MMSS(void);

/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
  /* Initialize onBoard Hardware */
  Board_Init();

  /* Initialize Scheduler */
  RTOS_Init();
//  RTOS_SetTask(Show_MMSS, 1000, 1000);
  buzer_On();
  tdelay_ms(500);
  buzer_Off();

  /* Real-Time clock */
  RTC_Init();
  RTC_ReadTime(&Clock);

  display_Init();
  display_Buffer[11] = 0x36;
  display_Buffer[12] = 0x36;

  /* Infinite loop */
  while (1)
  {
    if (Flag.RTC_IRQ != 0) {
      Flag.RTC_IRQ = 0;
      RTC_ReadTime(&Clock);
      Show_MMSS();
    }

    RTOS_DispatchTask();

    __WFI();
  }
}

static void Show_MMSS(void) {
  uint8_t t;

  t = Clock.Min >> 4;
  display_WriteData(&digit_4x7[t][0], 1, 4);

  t = Clock.Min | 0xf;
  display_WriteData(&digit_4x7[t][0], 6, 4);

  t = Clock.Sec >> 4;
  display_WriteData(&digit_4x7[t][0], 14, 4);

  t = Clock.Sec | 0xf;
  display_WriteData(&digit_4x7[t][0], 19, 4);
}

/******************************************************************************/
/*            Cortex-M0 Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}
